Struct LockFreeQueue
Source pub struct LockFreeQueue<T> { }
rust经典的无锁FIFO队列,
当前的实现,最多允许 多写1读
MPSC(multiple Producer, single Consumer)
allow multiple threads to call simultaneously
Executes the destructor for this type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.